@@ -195,3 +195,9 @@ def query_by_key_min_max(key_condition, table_name, is_min, dynamodb):
     print(e.response['Error']['Message'])
   else:
     return response['Items']
+
+def get_all_items_in_table(table_name, dynamodb):
+  table = dynamodb.Table(table_name)
+  response = table.scan()
+  items = response['Items']
+  return(items)
\ No newline at end of file
